@@ -16,4 +16,4 @@ def is_secure_transport(uri):
         return True
 
     uri = uri.lower()
-    return uri.startswith(("https://", "http://localhost:"))
+    return uri.startswith(("https://", "http://localhost:", "http://127.0.0.1:"))
