@@ -1,10 +1,10 @@
-class TokenEndpoint(object):
+class TokenEndpoint:
     #: Endpoint name to be registered
     ENDPOINT_NAME = None
     #: Supported token types
-    SUPPORTED_TOKEN_TYPES = ('access_token', 'refresh_token')
+    SUPPORTED_TOKEN_TYPES = ("access_token", "refresh_token")
     #: Allowed client authenticate methods
-    CLIENT_AUTH_METHODS = ['client_secret_basic']
+    CLIENT_AUTH_METHODS = ["client_secret_basic"]
 
     def __init__(self, server):
         self.server = server
@@ -18,10 +18,10 @@ class TokenEndpoint(object):
         return self.server.create_oauth2_request(request)
 
     def authenticate_endpoint_client(self, request):
-        """Authentication client for endpoint with ``CLIENT_AUTH_METHODS``.
-        """
+        """Authentication client for endpoint with ``CLIENT_AUTH_METHODS``."""
         client = self.server.authenticate_client(
-            request, self.CLIENT_AUTH_METHODS, self.ENDPOINT_NAME)
+            request, self.CLIENT_AUTH_METHODS, self.ENDPOINT_NAME
+        )
         request.client = client
         return client
 
