@@ -1,9 +1,11 @@
 from .code import OpenIDCode
-from .implicit import OpenIDImplicitGrant
+from .code import OpenIDToken
 from .hybrid import OpenIDHybridGrant
+from .implicit import OpenIDImplicitGrant
 
 __all__ = [
-    'OpenIDCode',
-    'OpenIDImplicitGrant',
-    'OpenIDHybridGrant',
+    "OpenIDToken",
+    "OpenIDCode",
+    "OpenIDImplicitGrant",
+    "OpenIDHybridGrant",
 ]
