@@ -1,17 +1,17 @@
+import json
 import os
 import time
-import json
-import requests
 from unittest import mock
 
+import requests
 
 ROOT = os.path.abspath(os.path.dirname(__file__))
 
 
 def read_key_file(name):
-    file_path = os.path.join(ROOT, 'keys', name)
-    with open(file_path, 'r') as f:
-        if name.endswith('.json'):
+    file_path = os.path.join(ROOT, "keys", name)
+    with open(file_path) as f:
+        if name.endswith(".json"):
             return json.load(f)
         return f.read()
 
@@ -23,6 +23,7 @@ def mock_text_response(body, status_code=200):
         resp.text = body
         resp.status_code = status_code
         return resp
+
     return fake_send
 
 
@@ -39,9 +40,9 @@ def mock_send_value(body, status_code=200):
 
 def get_bearer_token():
     return {
-        'token_type': 'Bearer',
-        'access_token': 'a',
-        'refresh_token': 'b',
-        'expires_in': '3600',
-        'expires_at': int(time.time()) + 3600,
+        "token_type": "Bearer",
+        "access_token": "a",
+        "refresh_token": "b",
+        "expires_in": "3600",
+        "expires_at": int(time.time()) + 3600,
     }
