@@ -27,9 +27,9 @@ class User(db.Model):
             "middle_name": "Middle",
             "nickname": "Jany",
             "preferred_username": "j.doe",
-            "profile": "https://example.com/janedoe",
-            "picture": "https://example.com/janedoe/me.jpg",
-            "website": "https://example.com",
+            "profile": "https://resource.test/janedoe",
+            "picture": "https://resource.test/janedoe/me.jpg",
+            "website": "https://resource.test",
             "email": "janedoe@example.com",
             "email_verified": True,
             "gender": "female",
